import { reactive, onMounted, ref, ElMessage, ElMessageBox, http, getGroupUrl, RegularVerification, verification, PaginationProps } from "@/utils/importUsed";
import { useRoute } from "vue-router";
import router from "@/router";
// 表单实例
const ruleFormRef = ref()
export function usePriDatabaseSet() {
  // 接口列表实例
  let UrlList = reactive(null)
  // 获取当前板块接口列表
  onMounted(async () => {
    const route = useRoute();
    form.projectId = Number(route.query.projectId);

    UrlList = await getGroupUrl(["prizeSet"]);
    onSearch(ruleFormRef.value);
    projectIdQuery();

  });
  let form = reactive({
    ipAddress: "", //IP地址
    userId: "", //用户名
    projectId: null, //项目


  });
  const dataList = ref([]);
  const loading = ref(false);
  const dialogAddVisible = ref(false);
  const pagination = reactive<PaginationProps>({
    total: 0,
    pageSize: 10,
    currentPage: 1,
    background: true
  });
  const columns: TableColumnList = [
    {
      type: "selection",
      width: 55,
      align: "left",
      hide: ({ checkList }) => !checkList.includes("勾选列")
    },
    {
      label: "序号",
      type: "index",
      width: 70,
      hide: ({ checkList }) => !checkList.includes("序号列")
    },
    {
      label: "ID",
      prop: "id",
      minWidth: 200
    },
    {
      label: "IP地址",
      prop: "ipAddress",
      minWidth: 200
    },
    {
      label: "端口",
      prop: "port",
      minWidth: 200
    },
    {
      label: "用户名",
      prop: "userId",
      minWidth: 200
    },
    {
      label: "密码",
      prop: "password",
      minWidth: 200
    },

    {
      label: "操作",
      fixed: "right",
      width: 200,
      slot: "operation"
    }
  ];
  // 当前页数量切换
  function handleSizeChange(val: number) {
    if (typeof val === "number") {
      pagination.pageSize = val;
      onSearch(ruleFormRef.value);
    }
  }
  // 当前页码切换
  function handleCurrentChange(val: number) {
    console.log(`current page: ${val}`);
    if (typeof val === "number") {
      pagination.currentPage = val;
      onSearch(ruleFormRef.value);
    }
  }
  // 选择表格项
  function handleSelectionChange(val) {
    console.log(`SelectionChange: ${val}`);
    onSearch(ruleFormRef.value);
  }
  // 搜索列表
  async function onSearch(formEl) {
    // 表单校验拦截
    if (!formEl) return
    await formEl.validate(async (valid, fields) => {
      if (valid) {
        //表单校验成功回调
        console.log('submit!')
        // 状态调整为加载中
        loading.value = true;
        // 调用接口（需动态生成接口）
        const { status, msg, data }: any = await http.Request({
          method: UrlList.prizeSet.prigetPriDatabaseSetList.method,
          url: UrlList.prizeSet.prigetPriDatabaseSetList.url,
          params: {
            ...form,
            pageSize: pagination.pageSize,
            pageNum: pagination.currentPage
          }
        });
        dataList.value = data.records;
        pagination.total = data.total;
        setTimeout(() => {
          loading.value = false;
        }, 500);
      } else {
        //表单校验失败回调
        ElMessage({
          message: "请输入完整信息",
          type: "error"
        });
      }
    })
  }
  // 项目选项数据
  const projectIdOptionList = ref([]);
  //获取项目数据
  async function projectIdQuery() {
    const { status, data }: any = await http.Request({ method: UrlList.prizeSet.prigetPriProjectDic.method, url: UrlList.prizeSet.prigetPriProjectDic.url, params: {} });
    if (status === 1) {
      projectIdOptionList.value = data.records;
    }
  }




  // 删除
  function handleDelete(row) {
    ElMessageBox.confirm(
      `是否删除该数据库连接配置? `,
      "提示",
      {
        confirmButtonText: "删除",
        cancelButtonText: "取消",
        type: "warning"
      }
    ).then(async () => {
      const { status, msg }: any = await http.Request({ method: UrlList.prizeSet.prideletePriDatabaseSet.method, url: UrlList.prizeSet.prideletePriDatabaseSet.url, params: String(row.id) });
      if (status === 1) {
        ElMessage({
          message: "删除成功",
          type: "success"
        });
        onSearch(ruleFormRef.value);
      } else {
        ElMessageBox.alert(msg, "提示", {
          confirmButtonText: "关闭",
          type: "warning"
        });
      };
    })
  }

  // 新增
  const addVisible = ref(false);
  function handleAdd() {
    addVisible.value = true;
  };

  // 修改
  const editUpdatePriDatabaseSetVisible = ref(false);
  const editUpdatePriDatabaseSetFormData = ref({});
  function handleUpdatePriDatabaseSet(row) {
    editUpdatePriDatabaseSetVisible.value = true;
    // 表格数据赋值
    editUpdatePriDatabaseSetFormData.value = row;
  };

  return {
    form,
    loading,
    columns,
    dataList,
    pagination,
    onSearch,
    handleSizeChange,
    handleCurrentChange,
    handleSelectionChange,
    ruleFormRef,
    projectIdQuery,
    projectIdOptionList,

    handleAdd,
    addVisible,
    handleUpdatePriDatabaseSet,
    editUpdatePriDatabaseSetVisible,
    editUpdatePriDatabaseSetFormData,
    handleDelete,

  };
}
