import { reactive, onMounted, ref, ElMessage, ElMessageBox, http, getGroupUrl, RegularVerification, verification, PaginationProps } from "@/utils/importUsed";
import { useRoute } from "vue-router";
import router from "@/router";
// 表单实例
const ruleFormRef = ref()
export function usePriProject() {
  // 接口列表实例
  let UrlList = reactive(null)
  // 获取当前板块接口列表
  onMounted(async () => {
    const route = useRoute();

    UrlList = await getGroupUrl(["prizeSet"]);
    onSearch(ruleFormRef.value);

  });
  let form = reactive({
    projectName: "", //项目名称
    requestMode: "", //调用方式


  });
  const dataList = ref([]);
  const loading = ref(false);
  const dialogAddVisible = ref(false);
  const pagination = reactive<PaginationProps>({
    total: 0,
    pageSize: 10,
    currentPage: 1,
    background: true
  });
  const columns: TableColumnList = [
    {
      type: "selection",
      width: 55,
      align: "left",
      hide: ({ checkList }) => !checkList.includes("勾选列")
    },
    {
      label: "序号",
      type: "index",
      width: 70,
      hide: ({ checkList }) => !checkList.includes("序号列")
    },
    {
      label: "ID",
      prop: "id",
      minWidth: 200
    },
    {
      label: "项目名称",
      prop: "projectName",
      minWidth: 200
    },
    {
      label: "调用方式",
      prop: "requestMode",
      minWidth: 200
    },
    {
      label: "是否通知",
      prop: "noticeFlag",
      minWidth: 200
    },
    {
      label: "请求地址",
      prop: "requestUrl",
      minWidth: 200
    },
    {
      label: "返回数据类型",
      prop: "returnType",
      minWidth: 200
    },

    {
      label: "操作",
      fixed: "right",
      width: 200,
      slot: "operation"
    }
  ];
  // 当前页数量切换
  function handleSizeChange(val: number) {
    if (typeof val === "number") {
      pagination.pageSize = val;
      onSearch(ruleFormRef.value);
    }
  }
  // 当前页码切换
  function handleCurrentChange(val: number) {
    console.log(`current page: ${val}`);
    if (typeof val === "number") {
      pagination.currentPage = val;
      onSearch(ruleFormRef.value);
    }
  }
  // 选择表格项
  function handleSelectionChange(val) {
    console.log(`SelectionChange: ${val}`);
    onSearch(ruleFormRef.value);
  }
  // 搜索列表
  async function onSearch(formEl) {
    // 表单校验拦截
    if (!formEl) return
    await formEl.validate(async (valid, fields) => {
      if (valid) {
        //表单校验成功回调
        console.log('submit!')
        // 状态调整为加载中
        loading.value = true;
        // 调用接口（需动态生成接口）
        const { status, msg, data }: any = await http.Request({
          method: UrlList.prizeSet.prigetPriProjectList.method,
          url: UrlList.prizeSet.prigetPriProjectList.url,
          params: {
            ...form,
            pageSize: pagination.pageSize,
            pageNum: pagination.currentPage
          }
        });
        dataList.value = data.records;
        pagination.total = data.total;
        setTimeout(() => {
          loading.value = false;
        }, 500);
      } else {
        //表单校验失败回调
        ElMessage({
          message: "请输入完整信息",
          type: "error"
        });
      }
    })
  }
  // 调用方式选项数据
  const requestModeOptionList = [
    { id: 'http', label: 'http' },
    { id: 'mq', label: 'MQ' },
  ]



  //跳转到入参表
  function linkToPriProjectParam(row) {
    router.push({ path: '../../pri/priProjectParam/index', query: { projectId: row.id } });
  }
  //跳转到条件匹配表
  function linkToPriQueryTable(row) {
    router.push({ path: '../../pri/priQueryTable/index', query: { projectId: row.id } });
  }
  //跳转到奖励配置
  function linkToPriList(row) {
    router.push({ path: '../../pri/priList/index', query: { projectId: row.id } });
  }
  //跳转到数据库连接配置
  function linkToPriDatabaseSet(row) {
    router.push({ path: '../../pri/priDatabaseSet/index', query: { projectId: row.id } });
  }
  //跳转到奖励发放对象表
  function linkToPriPrizeObjectTable(row) {
    router.push({ path: '../../pri/priPrizeObjectTable/index', query: { projectId: row.id } });
  }
  //跳转到请求和响应日志
  function linkToPriRequestLog(row) {
    router.push({ path: '../../pri/priRequestLog/index', query: { projectId: row.id } });
  }
  //跳转到递归开始条件对象表
  function linkToPriRecursionStartTable(row) {
    router.push({ path: '../../pri/priRecursionStartTable/index', query: { projectId: row.id } });
  }
  //跳转到递归停止条件对象表
  function linkToPriRecursionEndTable(row) {
    router.push({ path: '../../pri/priRecursionEndTable/index', query: { projectId: row.id } });
  }

  // 删除
  function handleDelete(row) {
    ElMessageBox.confirm(
      `是否删除该奖励项目? `,
      "提示",
      {
        confirmButtonText: "删除",
        cancelButtonText: "取消",
        type: "warning"
      }
    ).then(async () => {
      const { status, msg }: any = await http.Request({ method: UrlList.prizeSet.prideletePriProject.method, url: UrlList.prizeSet.prideletePriProject.url, params: String(row.id) });
      if (status === 1) {
        ElMessage({
          message: "删除成功",
          type: "success"
        });
        onSearch(ruleFormRef.value);
      } else {
        ElMessageBox.alert(msg, "提示", {
          confirmButtonText: "关闭",
          type: "warning"
        });
      };
    })
  }

  // 新增
  const addVisible = ref(false);
  function handleAdd() {
    addVisible.value = true;
  };

  // 修改
  const editUpdatePriProjectVisible = ref(false);
  const editUpdatePriProjectFormData = ref({});
  function handleUpdatePriProject(row) {
    editUpdatePriProjectVisible.value = true;
    // 表格数据赋值
    editUpdatePriProjectFormData.value = row;
  };

  return {
    form,
    loading,
    columns,
    dataList,
    pagination,
    onSearch,
    handleSizeChange,
    handleCurrentChange,
    handleSelectionChange,
    ruleFormRef,
    requestModeOptionList,

    handleAdd,
    addVisible,
    handleUpdatePriProject,
    editUpdatePriProjectVisible,
    editUpdatePriProjectFormData,
    handleDelete,
    linkToPriProjectParam,
    linkToPriQueryTable,
    linkToPriList,
    linkToPriDatabaseSet,
    linkToPriPrizeObjectTable,
    linkToPriRequestLog,
    linkToPriRecursionStartTable,
    linkToPriRecursionEndTable,

  };
}
